@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,9 +17,7 @@ NoteEditorUtilsTest::NoteEditorUtilsTest(QObject *parent)
 {
 }
 
-NoteEditorUtilsTest::~NoteEditorUtilsTest()
-{
-}
+NoteEditorUtilsTest::~NoteEditorUtilsTest() = default;
 
 void NoteEditorUtilsTest::testAddCheckmark_data()
 {
