@@ -9,7 +9,6 @@
 #include "knoteconfigdialog.h"
 #include "config/noteactionconfig.h"
 #include "config/notenetworkconfig.h"
-#include "kcoreaddons_version.h"
 #include "knotesglobalconfig.h"
 #include "notesharedglobalconfig.h"
 #include "print/knoteprintselectthemecombobox.h"
@@ -31,7 +30,8 @@ KNoteConfigDialog::KNoteConfigDialog(const QString &title, QWidget *parent)
     button(QDialogButtonBox::Ok)->setDefault(true);
 
     setWindowTitle(title);
-    const QVector<KPluginMetaData> availablePlugins = KPluginMetaData::findPlugins(QStringLiteral("pim/kcms/knotes"));
+    const QVector<KPluginMetaData> availablePlugins =
+        KPluginMetaData::findPlugins(QStringLiteral("pim" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/kcms/knotes"));
     for (const KPluginMetaData &metaData : availablePlugins) {
         addModule(metaData);
     }
@@ -40,9 +40,7 @@ KNoteConfigDialog::KNoteConfigDialog(const QString &title, QWidget *parent)
     connect(button(QDialogButtonBox::RestoreDefaults), &QPushButton::clicked, this, &KNoteConfigDialog::slotDefaultClicked);
 }
 
-KNoteConfigDialog::~KNoteConfigDialog()
-{
-}
+KNoteConfigDialog::~KNoteConfigDialog() = default;
 
 void KNoteConfigDialog::slotOk()
 {
